@@ -11,7 +11,6 @@ typedef struct W_Label {
     W_View *view;
 	
     char *caption;
-    int captionHeight;
 
     WMColor *textColor;
     WMFont *font;		       /* if NULL, use default */
@@ -22,20 +21,14 @@ typedef struct W_Label {
 	WMReliefType relief:3;
 	WMImagePosition imagePosition:4;
 	WMAlignment alignment:2;
+	
+	unsigned int noWrap:1;
 
 	unsigned int redrawPending:1;
     } flags;
 } Label;
 
 
-
-W_ViewProcedureTable _LabelViewProcedures = {
-    NULL,
-	NULL,
-	NULL
-};
-
-
 #define DEFAULT_WIDTH		60
 #define DEFAULT_HEIGHT		14
 #define DEFAULT_ALIGNMENT	WALeft
@@ -97,6 +90,14 @@ WMSetLabelImage(WMLabel *lPtr, WMPixmap *image)
     }
 }
 
+
+WMPixmap*
+WMGetLabelImage(WMLabel *lPtr)
+{
+    return lPtr->image;
+}
+
+
 void
 WMSetLabelImagePosition(WMLabel *lPtr, WMImagePosition position)
 {
@@ -125,7 +126,8 @@ WMSetLabelRelief(WMLabel *lPtr, WMReliefType relief)
 	paintLabel(lPtr);
     }
 }
-	
+
+
 void
 WMSetLabelText(WMLabel *lPtr, char *text)
 {
@@ -134,12 +136,8 @@ WMSetLabelText(WMLabel *lPtr, char *text)
     
     if (text!=NULL) {
 	lPtr->caption = wstrdup(text);
-	lPtr->captionHeight =
-	    W_GetTextHeight(lPtr->font ? lPtr->font : lPtr->view->screen->normalFont,
-			    lPtr->caption, lPtr->view->size.width, True);
     } else {
 	lPtr->caption = NULL;
-	lPtr->captionHeight = 0;
     }
     if (lPtr->view->flags.realized) {
 	paintLabel(lPtr);
@@ -157,12 +155,6 @@ WMSetLabelFont(WMLabel *lPtr, WMFont *font)
     else
 	lPtr->font = NULL;
 
-    if (lPtr->caption) {
-	lPtr->captionHeight =
-	    W_GetTextHeight(lPtr->font ? lPtr->font : lPtr->view->screen->normalFont,
-			    lPtr->caption, lPtr->view->size.width, True);
-    }
-    
     if (lPtr->view->flags.realized) {
 	paintLabel(lPtr);
     }
@@ -178,6 +170,17 @@ WMSetLabelTextColor(WMLabel *lPtr, WMColor *color)
 }
 
 
+void
+WMSetLabelWraps(WMLabel *lPtr, Bool flag)
+{
+    if (lPtr->flags.noWrap != !flag) {
+	lPtr->flags.noWrap = !flag;
+	if (lPtr->view->flags.realized)
+	    paintLabel(lPtr);
+    }
+}
+
+
 static void
 paintLabel(Label *lPtr)
 {
@@ -185,13 +188,13 @@ paintLabel(Label *lPtr)
     GC gc;
     
     if (lPtr->textColor)
-	gc = W_GC(lPtr->textColor);
+	gc = WMColorGC(lPtr->textColor);
     else
-	gc = W_GC(scrPtr->black);
+	gc = WMColorGC(scrPtr->black);
 
-    W_PaintTextAndImage(lPtr->view, True, gc,
+    W_PaintTextAndImage(lPtr->view, !lPtr->flags.noWrap, gc,
 			(lPtr->font!=NULL ? lPtr->font : scrPtr->normalFont),
-			lPtr->flags.relief, lPtr->caption, lPtr->captionHeight,
+			lPtr->flags.relief, lPtr->caption,
 			lPtr->flags.alignment, lPtr->image, 
 			lPtr->flags.imagePosition, NULL, 0);
 }
